/**
 * SWE KEx-DatexII (de.bsvrz.kex.datex2)
 * 
 * Copyright (C) 2014 TraffGo Road GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * TraffGo Road GmbH
 * Ostwall 11-19
 * 47798 Krefeld
 * Phone: +49-2151-3295058
 * mailto: info@traffgoroad.de
 */

package de.bsvrz.kex.datex2.allgemein.impl;

import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.List;
import java.util.Properties;

import de.bsvrz.kex.datex2.allgemein.KonfigurationsModul;
import de.bsvrz.kex.datex2.allgemein.KonfigurationsModuleFactory;
import de.bsvrz.sys.funclib.debug.Debug;

/**
 * Klasse zur Instantiierung von Konfigurationsmodulen in verschiedenen Kontexten.
 * Es werden Klassen "EinfachesKonfigurationsModul" instantiiert, die Kontexte werden
 * aus dem Scan eines Verzeichnisses abgeleitet.
 * 
 * @author TraffGo Road GmbH
 * @version $Id$
 */

public class EinfachesKonfigurationsModulFactory implements
    KonfigurationsModuleFactory {
  /** Verzeichnis, in dem Dateien als Konfigurationsdateien vorliegen. */
  private String pfad;
  
  /** Logging. */
  private static final Debug LOGGER = Debug.getLogger();
  
  /**
   * Konstruktor. Initialisiert die Factory-Klasse mit einem konkreten Pfad.
   * 
   * @param pfad Verzeichnis, in dem Dateien als Konfigurationsdateien vorliegen
   */
  public EinfachesKonfigurationsModulFactory(final String pfad) {
    this.pfad = pfad;
  }

  @Override
  public List<KonfigurationsModul> instantiiere() {
    List<KonfigurationsModul> result = new ArrayList<>();
    File ordner = new File(pfad);
    try {
       for (File file : ordner.listFiles()) {       
         if (file.isFile()) {
           try {
             result.add(new EinfachesKonfigurationsModul(file));
           } catch (Exception e) {
             LOGGER.warning(e.getMessage());
           }
         }
       }
    } catch (Exception e) {
      LOGGER.error(e.getMessage());
    }
    return result;
  }

  /**
   * Liest den Inhalt aller Konfigurationsdatein und speichert
   * sie in einer Liste von Property-Objekten.
   * 
   * @param cnf
   *          Name des Ordners, in dem die Konfigurationsdateien gespeichert sind
   * @return Liste mit den Properties aller Plug-Ins
   * @throws Exception
   *           Falls ein Fehler beim Lesen der dateien auftritt
   */
  
  protected List<Properties> leseKonfigurationen(final String cnf) 
      throws Exception { 
   List<Properties> confListe = new ArrayList<>();
   File ordner = new File(cnf);
   try {
      for (File file : ordner.listFiles()) {
        if (file.isFile()) {
          Properties prop = new Properties();
          InputStream inputStream = new FileInputStream(file);
          prop.load(inputStream);
          confListe.add(prop);
        }
      }
    } catch (Exception e) {
       LOGGER.error(e.getMessage());
    }
   
   return confListe;
  } 
}
