/*
 * Plug-in KEx DATEX II - Baustellen
 * Copyright (C) 2018 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.datex2.plugins.konvertierung.impl;

import de.bsvrz.dav.daf.main.Data;
import eu.datex2.schema.dynamisch.baustellen.AlertCDirection;
import eu.datex2.schema.dynamisch.baustellen.AlertCDirectionEnum;
import eu.datex2.schema.dynamisch.baustellen.AlertCLinear;
import eu.datex2.schema.dynamisch.baustellen.AlertCMethod4Linear;
import eu.datex2.schema.dynamisch.baustellen.Linear;
import eu.datex2.schema.dynamisch.baustellen.LinearReferencingDirectionEnum;
import eu.datex2.schema.dynamisch.baustellen.LinearWithinLinearElement;

/**
 * Wrapper f&uuml;r {@link Linear}.
 *
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id: $
 */

public class Datex2OrtsreferenzenLinear extends Linear {
	Datex2OrtsreferenzenLinear(final Data data) throws Datex2BaustelleException {
		super();
		if (data.getArray("OrtsRefAlertC").getLength() > 0) {
			setAlertCLinear((new Datex2OrtsreferenzenAlertCLinear(data.getArray("OrtsRefAlertC"))).getAlertCLinear());
		}
		if (data.getArray("OrtsRefAsb").getLength() > 0) {
			setLinearWithinLinearElement(new Datex2AsbLocationLinear(data.getArray("OrtsRefAsb")));
		}
	}

	/**
	 * Setzt das Flag, ob die Ortsreferenz in beiden Richtungen gilt.
	 * 
	 * @param beideRichtungen
	 *            <code>true</code> wenn beide Richtungen
	 */
	public void setBeideRichtungen(final boolean beideRichtungen) {
		if (beideRichtungen) {
			final AlertCLinear alertCLinear2 = getAlertCLinear();
			if (alertCLinear2 != null) {
				if (alertCLinear2 instanceof AlertCMethod4Linear) {
					final AlertCDirection alertCDirection = new AlertCDirection();
					alertCDirection.setAlertCDirectionCoded(AlertCDirectionEnum.BOTH);
					((AlertCMethod4Linear) alertCLinear2).setAlertCDirection(alertCDirection);
				}
			}

			final LinearWithinLinearElement linearWithinLinearElement = getLinearWithinLinearElement();
			if (linearWithinLinearElement != null) {
				linearWithinLinearElement.setDirectionRelativeOnLinearSection(LinearReferencingDirectionEnum.BOTH);
			}
		}
	}
}
