/*
 * Plug-in KEx DATEX II - Baustellen
 * Copyright (C) 2018 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.datex2.plugins.konvertierung.impl;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.ResultData;
import de.bsvrz.kex.datex2.plugins.konvertierung.impl.elemente.Datex2ArtDerMassnahmeEnum;
import eu.datex2.schema.dynamisch.baustellen.ObjectFactory;

/**
 * Factory zur Erzeugung der passenden SituationRecords entsprechend der
 * ArtDerMassnahme.
 * 
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id: $
 */

public final class Datex2SituationRecordFactory {

	private Datex2SituationRecordFactory() {
	}

	static Datex2BaustelleExportIF createSituationRecord(final String prefix, final ResultData resultData,
			final Data data) throws Datex2BaustelleException {

		final ObjectFactory objectFactory = new ObjectFactory();

		final Data item = data.getItem(prefix + "ArtDerMassnahme");
		final Datex2ArtDerMassnahmeEnum instance = Datex2ArtDerMassnahmeEnum
				.getInstance(item.asUnscaledValue().intValue());

		if (instance.getConstructionWorkTypeEnum() != null) {
			return new Datex2ContructionWorks(objectFactory.createConstructionWorks(), prefix, resultData, data);
		}

		if (instance.getRoadMaintenanceTypeEnum() != null) {
			return new Datex2MaintenanceWorks(objectFactory.createMaintenanceWorks(), prefix, resultData, data);
		}

		if (instance.getRoadOrCarriagewayOrLaneManagementTypeEnum() != null) {
			return new Datex2RoadOrCarriagewayOrLaneManagement(objectFactory.createRoadOrCarriagewayOrLaneManagement(),
					prefix, resultData, data);
		}

		throw new Datex2BaustelleException(
				"Kein SituationRecordType fuer Datex2ArtDerMassnahmeEnum: " + instance.toString());
	}
}
