/**
 * SWE KEx-DatexII (de.bsvrz.kex.datex2)
 * 
 * Copyright (C) 2014 TraffGo Road GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * TraffGo Road GmbH
 * Ostwall 11-19
 * 47798 Krefeld
 * Phone: +49-2151-3295058
 * mailto: info@traffgoroad.de
 */

package de.bsvrz.kex.datex2.plugins.konvertierung.impl;

import java.util.Collection;
import java.util.Date;
import java.util.Map;

import javax.naming.ConfigurationException;
import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.datatype.XMLGregorianCalendar;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.Data.Array;
import de.bsvrz.dav.daf.main.ResultData;
import de.bsvrz.kex.datex2.allgemein.ObjekteAtgAsp;
import de.bsvrz.kex.datex2.plugins.definition.PluginExport;
import eu.datex2.schema.dynamisch.routen.reisezeiten.ConfidentialityValueEnum;
import eu.datex2.schema.dynamisch.routen.reisezeiten.CountryEnum;
import eu.datex2.schema.dynamisch.routen.reisezeiten.D2LogicalModel;
import eu.datex2.schema.dynamisch.routen.reisezeiten.DurationValue;
import eu.datex2.schema.dynamisch.routen.reisezeiten.ElaboratedData;
import eu.datex2.schema.dynamisch.routen.reisezeiten.ElaboratedDataPublication;
import eu.datex2.schema.dynamisch.routen.reisezeiten.Exchange;
import eu.datex2.schema.dynamisch.routen.reisezeiten.HeaderInformation;
import eu.datex2.schema.dynamisch.routen.reisezeiten.InformationStatusEnum;
import eu.datex2.schema.dynamisch.routen.reisezeiten.InternationalIdentifier;
import eu.datex2.schema.dynamisch.routen.reisezeiten.LocationByReference;
import eu.datex2.schema.dynamisch.routen.reisezeiten.MultilingualString;
import eu.datex2.schema.dynamisch.routen.reisezeiten.MultilingualString.Values;
import eu.datex2.schema.dynamisch.routen.reisezeiten.MultilingualStringValue;
import eu.datex2.schema.dynamisch.routen.reisezeiten.PayloadPublication;
import eu.datex2.schema.dynamisch.routen.reisezeiten.PredefinedLocationVersionedReference;
import eu.datex2.schema.dynamisch.routen.reisezeiten.PredefinedNonOrderedLocationGroupVersionedReference;
import eu.datex2.schema.dynamisch.routen.reisezeiten.ReferenceSettings;
import eu.datex2.schema.dynamisch.routen.reisezeiten.Source;
import eu.datex2.schema.dynamisch.routen.reisezeiten.TravelTimeData;

/**
 * Konvertierung von dynamischen Verkehrsdaten der NBAs (Reisezeiten) in das DATEX-II Format.
 * 
 * @author TraffGo Road GmbH
 * @version $Id$
 */

public class RSReisezeit extends StandardKonvertierungDynamisch {  
  /**
   * Konstruktor.
   * 
   * @param plugin Plugin-Definitions-Klasse.
   */
  
  public RSReisezeit(final PluginExport plugin) {
    this.plugin = plugin;
  }
  
  /***************************************************************************
   * IN DEM FOLGENDEN ABSCHNITT WERDEN STRUKTURELL GLEICHE METHODEN GESAMMELT.
   * 
   * Diese Methoden werden in den einzelnen Plugins wiederholt - allerdings
   * beziehen sich die JAXB-Elemente trotz gleichen Namens dann auf
   * andere Klassen; eine nominale Gleichheit existiert also nicht.
   ***************************************************************************
   */

  /**
   * Gebe den in dieser Klasse verwendeten JAXBContext zurück. 
   * 
   * @throws JAXBException JAXBException
   * @see javax.xml.bind.JAXBContext#newInstance(String)
   * @return JAXBContext Verwendeter Kontext
   */

  @Override
  public JAXBContext getJAXBContext() throws JAXBException {
    if (jaxbContext == null) {
      jaxbContext = JAXBContext.newInstance(D2LogicalModel.class.getPackage().getName());
    }
    return jaxbContext;
  }

  /**
   * Setzt die allgemeinen Angaben zur Publikation (Exchange, Language, PublicationCreator).
   * 
   * @param d2l D2LogicalModel
   * @param payload Verwendeter Payload
   */

  private void setzeNationalIdentifier(final D2LogicalModel d2l, final PayloadPublication payload) {
    InternationalIdentifier internationalIdentifier = new InternationalIdentifier();
    internationalIdentifier.setCountry(CountryEnum.DE);
    internationalIdentifier.setNationalIdentifier(nationalIdentifier);
    
    // Setze Exchange
    
    Exchange exchange = new Exchange();
    exchange.setSupplierIdentification(internationalIdentifier);
    d2l.setExchange(exchange);

    // Setze Language
    payload.setLang("DE");

    payload.setPublicationCreator(internationalIdentifier);
  }

  
  /***********************************************************************
   * ENDE DES ABSCHNITTS STRUKTURELL GLEICHER METHODEN
   ***********************************************************************
   */
  
  /** {@inheritDoc} */
  @Override
  public Object getDatexII(final Map<ObjekteAtgAsp, Collection<ResultData>> data) {
    String predefinedLocationVersion = holePredefinedLocationVersion();

    D2LogicalModel d2l = new D2LogicalModel();
    ElaboratedDataPublication payload = new ElaboratedDataPublication();

    // Schema-Default-Angaben setzen

    d2l.setExtensionName(d2l.getExtensionName());
    d2l.setExtensionVersion(d2l.getExtensionVersion());

    setzeNationalIdentifier(d2l, payload);
    HeaderInformation headerInformation = new HeaderInformation();
    headerInformation.setConfidentiality(ConfidentialityValueEnum.RESTRICTED_TO_AUTHORITIES);
    headerInformation.setInformationStatus(InformationStatusEnum.REAL);
    payload.setLang("DE");
    InternationalIdentifier internationalIdentifier = new InternationalIdentifier();
    internationalIdentifier.setCountry(CountryEnum.DE);

    internationalIdentifier.setNationalIdentifier(nationalIdentifier);
    Exchange exchange = new Exchange();
    exchange.setSupplierIdentification(internationalIdentifier);
    d2l.setExchange(exchange);
    ReferenceSettings referenceSettings = new ReferenceSettings();
    PredefinedNonOrderedLocationGroupVersionedReference predefinedNonOrderedLocationGroupVersionedReference =
        new PredefinedNonOrderedLocationGroupVersionedReference();
    predefinedNonOrderedLocationGroupVersionedReference.setId(locationGroupId);
    predefinedNonOrderedLocationGroupVersionedReference.setVersion(predefinedLocationVersion);
    referenceSettings.setPredefinedNonOrderedLocationGroupReference(predefinedNonOrderedLocationGroupVersionedReference);

    payload.setPublicationCreator(internationalIdentifier);
    payload.setHeaderInformation(headerInformation);
    payload.setReferenceSettings(referenceSettings);
    payload.setForecastDefault(true);

    Date datum = new Date();
    XMLGregorianCalendar xmlGregorianCalendar = WerkzeugSammlung.konvertiereDatum(datum);
    payload.setPublicationTime(xmlGregorianCalendar);

    for (ObjekteAtgAsp objekteAtgAsp : data.keySet()) {
      for (ResultData resultData : data.get(objekteAtgAsp)) {	
        if (resultData != null) { 
          try {  	
            LocationByReference locationByReference = new LocationByReference();
            PredefinedLocationVersionedReference predefinedLocationVersionedReference = 
                new PredefinedLocationVersionedReference();
            predefinedLocationVersionedReference.setId(resultData.getObject().getId() + "");
            predefinedLocationVersionedReference.setVersion(predefinedLocationVersion);
            locationByReference.setPredefinedLocationReference(predefinedLocationVersionedReference);
            payload = setTravelTime(payload, resultData, locationByReference);
          } catch (Exception e) {
            LOGGER.warning("Daten nicht berücksichtigt.", e);
          }
        } //if(resultData != null)	        
      } // end for 
    } // end for

    d2l.setPayloadPublication(payload);

    if (payload.getElaboratedDatas().isEmpty()) {
      LOGGER.warning(logPrefix + "Kein valider Datensatz verfügbar, Publikation wird abgebrochen");
      return null;
    } else { 
      return d2l;
    }
  }

  /**
   * Setzt die Reisezeit aus Resultdata und erweitert die ElaboratedDataPublication.
   * 
   * @param payload
   *          ElaboratedDataPublication
   * @param resultData 
   * 			ResultData 
   * @param locationByReference 
   * 			LocationByReference 
   * @return ElaboratedDataPublication
   */

  protected ElaboratedDataPublication setTravelTime(final ElaboratedDataPublication payload, 
      final ResultData resultData, final LocationByReference locationByReference) {

    if (resultData.hasData()) {
      Array reisezeitArray = resultData.getData().getArray("ReisezeitPrognose");
      for (int i = 0; i < reisezeitArray.getLength(); i++) {
        Data d = reisezeitArray.getItem(i);
        long referenzZeit = d.getTimeValue("Zeitpunkt").getMillis();
        XMLGregorianCalendar xmlReferenzZeit = WerkzeugSammlung.konvertiereDatum(referenzZeit);

        long reisezeit1 =  d.getTimeValue("Reisezeit").getSeconds();
        long reisezeit2 =  d.getTimeValue("ReisezeitAlg2").getSeconds();
        ElaboratedData elaboratedDataZeit1 = new ElaboratedData();
        TravelTimeData travelTimeData1 = new TravelTimeData();
        DurationValue durationValue1 = new DurationValue();
        Source source1 = new Source();
        source1.setSourceName(konvertiereString("bei Überlastung der Strecke berechnet durch Korrektur"));
        durationValue1.setDuration(reisezeit1);
        travelTimeData1.setMeasurementOrCalculationTime(xmlReferenzZeit);
        travelTimeData1.setPertinentLocation(locationByReference);
        travelTimeData1.setTravelTime(durationValue1);
        elaboratedDataZeit1.setBasicData(travelTimeData1);
        elaboratedDataZeit1.setSource(source1);
        payload.getElaboratedDatas().add(elaboratedDataZeit1);
        ElaboratedData elaboratedDataZeit2 = new ElaboratedData();
        TravelTimeData travelTimeData2 = new TravelTimeData();
        DurationValue durationValue2 = new DurationValue();
        Source source2 = new Source();
        source2.setSourceName(konvertiereString("bei Überlastung der Strecke berechnet mit Stau in der Zukunft"));
        durationValue2.setDuration(reisezeit2);
        travelTimeData2.setMeasurementOrCalculationTime(xmlReferenzZeit);
        travelTimeData2.setPertinentLocation(locationByReference);
        travelTimeData2.setTravelTime(durationValue2);
        elaboratedDataZeit2.setBasicData(travelTimeData2);
        elaboratedDataZeit2.setSource(source2);
        payload.getElaboratedDatas().add(elaboratedDataZeit2);
      }
    }
    return payload;

  }

  /**
   * erzeugt einen Multilingualen String.
   * 
   * @param s
   *          Text für den deutschen Text des Multiligualen Strings
   * @return MultilingualString
   */

  protected static MultilingualString konvertiereString(final String s) {
    MultilingualString ms = new MultilingualString();
    Values vs = new Values();
    MultilingualStringValue msv = new MultilingualStringValue();
    msv.setLang("DE");
    msv.setValue(s);
    vs.getValues().add(msv);
    ms.setValues(vs);
    return ms;
  }

  @Override
  public void initialisiere(final Collection<ObjekteAtgAsp> objects) throws ConfigurationException {
    initialisiereBasisFelder();
    initialisiereStandardIntervall();
  }

}
