/*
 * Plug-in KEx DATEX II - Baustellen
 * Copyright (C) 2018 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.datex2.plugins.konvertierung.impl.elemente;

import de.bsvrz.kex.datex2.plugins.konvertierung.impl.Datex2BaustelleException;
import eu.datex2.schema.dynamisch.baustellen.ConstructionWorkTypeEnum;
import eu.datex2.schema.dynamisch.baustellen.RoadMaintenanceTypeEnum;
import eu.datex2.schema.dynamisch.baustellen.RoadOrCarriagewayOrLaneManagementTypeEnum;
import eu.datex2.schema.dynamisch.baustellen.SubjectTypeOfWorksEnum;

/**
 * Umsetzung Datk <code>att.mdmBisArtDerMassnahme</code> in Datex2
 * <code>actionPlanIdentifier</code>. <br>
 * Dieses ENUM implementiert die Abbildung 20 aus
 * MDM_Datenmodell_Baustellen_04-00-00.pdf.
 * 
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id: $
 */
public enum Datex2ArtDerMassnahmeEnum {

	/**
	 * Straßenneubau&nbsp;1&nbsp;Straßenneubau (DATEX II:
	 * SituationRecord-constructionWorkType,comment-Straßenneubau,
	 * actionPlanIdentifier-A1).
	 */
	Strassenneubau("Straßenneubau", "A1", 1, null, ConstructionWorkTypeEnum.CONSTRUCTION_WORK, null, null),

	/**
	 * Straßenausbau&nbsp;2&nbsp;Straßenausbau (DATEX II:
	 * SituationRecord-constructionWorkType,comment-Straßenausbau,
	 * actionPlanIdentifier-A2).
	 */
	Strassenausbau("Straßenausbau", "A2", 2, null, ConstructionWorkTypeEnum.ROAD_WIDENING_WORK, null, null),

	/**
	 * Straßenumbau&nbsp;3&nbsp;Straßenumbau (DATEX II:
	 * SituationRecord-constructionWorkType, comment-Straßenumbau,
	 * actionPlanIdentifier-A3).
	 */
	Strassenumbau("Straßenumbau", "A3", 3, null, ConstructionWorkTypeEnum.ROAD_IMPROVEMENT_OR_UPGRADING, null, null),

	/**
	 * Unterhaltungsarbeiten&nbsp;4&nbsp;Unterhaltungsarbeiten (DATEX II:
	 * SituationRecord-roadMaintanceType, comment-Unterhaltungsarbeiten,
	 * actionPlanIdentifier-A3).
	 */
	Unterhaltungsarbeiten("Unterhaltungsarbeiten", "A4", 4, RoadMaintenanceTypeEnum.MAINTENANCE_WORK, null, null, null),

	/**
	 * Instandsetzung Deckschicht&nbsp;5&nbsp;Instandsetzung auf/an der
	 * Deckschicht (DATEX II: SituationRecord-roadMaintanceType,
	 * comment-Instandsetzung auf/an der Deckschicht, actionPlanIdentifier-F1).
	 */
	InstandsetzungDeckschicht("Instandsetzung Deckschicht", "F1", 5, RoadMaintenanceTypeEnum.REPAIR_WORK, null, null, SubjectTypeOfWorksEnum.ROAD),

	/**
	 * Erneuerung Decke 6 Erneuerung an der Decke (DATEX II:
	 * SituationRecord-roadMaintanceType, comment-Erneuerung an der Decke,
	 * actionPlanIdentifier-F2).
	 */
	ErneuerungDecke("Erneuerung Decke", "F2", 6, RoadMaintenanceTypeEnum.RESURFACING_WORK, null, null, null),

	/**
	 * Erneuerung an der Tragschicht / Oberbau (DATEX II:
	 * SituationRecord-roadMaintanceType,comment-Erneuerung an der Tragschicht /
	 * Oberbau, actionPlanIdentifier-F3).
	 */
	ErneuerungTragschichtOberbau("Erneuerung Tragschicht / Oberbau", "F3", 7, RoadMaintenanceTypeEnum.RESURFACING_WORK, null, null, null),

	/**
	 * Erneuerung der Fahrbahn (DATEX II: SituationRecord-roadMaintanceType,
	 * comment-Erneuerung der Fahrbahn, actionPlanIdentifier-F4).
	 */
	ErneuerungDerFahrbahn("Erneuerung der Fahrbahn", "F4", 8, RoadMaintenanceTypeEnum.RESURFACING_WORK, null, null, null),

	/**
	 * Fahrbahninstandsetzung (DATEX II: SituationRecord-roadMaintanceType,
	 * comment-Fahrbahninstandsetzung, actionPlanIdentifier-F5).
	 */
	Fahrbahninstandsetzung("Erneuerung der Fahrbahn", "F5", 9, RoadMaintenanceTypeEnum.REPAIR_WORK, null, null, SubjectTypeOfWorksEnum.ROAD),

	/**
	 * Fahrbahninstandhaltung (DATEX II: SituationRecord-roadMaintanceType,
	 * comment-Fahrbahninstandhaltung, actionPlanIdentifier-F6).
	 */
	Fahrbahninstandhaltung("Fahrbahninstandhaltung", "F6", 10, RoadMaintenanceTypeEnum.MAINTENANCE_WORK, null, null, SubjectTypeOfWorksEnum.ROAD),

	/**
	 * Verbreiterung der Fahrbahn (DATEX II:
	 * SituationRecord-constructionWorkType, comment-Verbreiterung der Fahrbahn,
	 * actionPlanIdentifier-V1).
	 */
	VerbreiterungFahrbahn("Verbreiterung Fahrbahn", "V1", 11, null, ConstructionWorkTypeEnum.ROAD_WIDENING_WORK, null, null),

	/**
	 * Anbau von Fahrstreifen (DATEX II: SituationRecord-constructionWorkType,
	 * comment-Anbau von Fahrstreifen, actionPlanIdentifier-V2).
	 */
	AnbauFahrstreifen("Anbau Fahrstreifen", "V2", 12, null, ConstructionWorkTypeEnum.ROAD_WIDENING_WORK, null, null),

	/**
	 * Anbau von Seitenstreifen (DATEX II: SituationRecord-constructionWorkType,
	 * comment-Anbau von Seitenstreifen, actionPlanIdentifier-V3).
	 */
	AnbauSeitenstreifen("Anbau Seitenstreifen", "V3", 13, null, ConstructionWorkTypeEnum.ROAD_WIDENING_WORK, null, null),

	/**
	 * Neubau einer Anschlussstelle (DATEX II:
	 * SituationRecord-constructionWorkType, comment-Neubau einer
	 * Anschlussstelle, actionPlanIdentifier-AS1).
	 */
	NeubauAnschlussstelle("Neubau Anschlussstelle", "AS1", 14, null, ConstructionWorkTypeEnum.CONSTRUCTION_WORK, null, SubjectTypeOfWorksEnum.JUNCTION),

	/**
	 * Sperrung einer Anschlussstelle (DATEX II:
	 * SituationRecord-roadOrCarriagewayOrLaneManagementType, comment-Sperrung
	 * einer Anschlussstelle, actionPlanIdentifier-AS2).
	 */
	SperrungAnschlussstelle("Sperrung Anschlussstelle", "AS2", 15, null, null, RoadOrCarriagewayOrLaneManagementTypeEnum.CARRIAGEWAY_CLOSURES, SubjectTypeOfWorksEnum.JUNCTION),

	/**
	 * Umbau einer Anschlussstelle (DATEX II:
	 * SituationRecord-constructionWorkType, comment-Umbau einer
	 * Anschlussstelle, actionPlanIdentifier-AS3).
	 */
	UmbauAnschlussstelle("Umbau Anschlussstelle", "AS3", 16, null, ConstructionWorkTypeEnum.ROAD_IMPROVEMENT_OR_UPGRADING, null, SubjectTypeOfWorksEnum.JUNCTION),

	/**
	 * Sperrung Richtungsfahrbahn (DATEX II:
	 * SituationRecord-roadOrCarriagewayOrLaneManagementType, comment-Sperrung
	 * Richtungsfahrbahn, actionPlanIdentifier-SP1).
	 */
	SperrungRichtungsfahrbahn("Sperrung Richtungsfahrbahn", "SP1", 17, null, null, RoadOrCarriagewayOrLaneManagementTypeEnum.ROAD_CLOSED, null),

	/**
	 * Sperrung im Knotenpunkt (DATEX II:
	 * SituationRecord-roadOrCarriagewayOrLaneManagementType, comment-Sperrung
	 * im Knotenpunkt, actionPlanIdentifier-SP2).
	 */
	SperrungKnotenpunkt("Sperrung Knotenpunkt", "SP2", 18, null, null, RoadOrCarriagewayOrLaneManagementTypeEnum.CARRIAGEWAY_CLOSURES, SubjectTypeOfWorksEnum.INTERCHANGE),

	/**
	 * Brückenneubau (DATEX II: SituationRecord-constructionWorkType,
	 * comment-Brückenneubau, actionPlanIdentifier-B1).
	 */
	Brueckenneubau("Brückenneubau", "B1", 19, null, ConstructionWorkTypeEnum.CONSTRUCTION_WORK, null, SubjectTypeOfWorksEnum.BRIDGE),

	/**
	 * Brückenumbau (DATEX II: SituationRecord-constructionWorkType,
	 * comment-Brückenumbau, actionPlanIdentifier-B2).
	 */
	Brueckenumbau("Brückenumbau", "B2", 20, null, ConstructionWorkTypeEnum.CONSTRUCTION_WORK, null, SubjectTypeOfWorksEnum.BRIDGE),

	/**
	 * Brückeninstandsetzung (DATEX II: SituationRecord-roadMaintanceType,
	 * comment-Brückeninstandsetzung, actionPlanIdentifier-B3).
	 */
	Brueckeninstandsetzung("Brückeninstandsetzung", "B3", 21, RoadMaintenanceTypeEnum.REPAIR_WORK, null, null, SubjectTypeOfWorksEnum.BRIDGE),

	/**
	 * Brückenwartung (DATEX II: SituationRecord-roadMaintanceType,
	 * comment-Brückenwartung, actionPlanIdentifier-B4).
	 */
	Brueckenwartung("Brückenwartung", "B4", 22, RoadMaintenanceTypeEnum.MAINTENANCE_WORK, null, null, SubjectTypeOfWorksEnum.BRIDGE),

	/**
	 * Tunnelneubau (DATEX II: SituationRecord-constructionWorkType,
	 * comment-Tunnelneubau, actionPlanIdentifier-B6).
	 */
	Tunnelneubau("Tunnelneubau", "B6", 23, null, ConstructionWorkTypeEnum.CONSTRUCTION_WORK, null, SubjectTypeOfWorksEnum.TUNNEL),

	/**
	 * Tunnelnachrüstung (DATEX II: SituationRecord-roadMaintanceType,
	 * comment-Tunnelnachrüstung, actionPlanIdentifier-B7).
	 */
	Tunnelnachruestung("Tunnelnachrüstung", "B7", 24, RoadMaintenanceTypeEnum.REPAIR_WORK, null, null, SubjectTypeOfWorksEnum.TUNNEL),

	/**
	 * TTunnelinstandsetzung (DATEX II: SituationRecord-roadMaintanceType,
	 * comment-Tunnelinstandsetzung, actionPlanIdentifier-B8).
	 */
	Tunnelinstandsetzung("Tunnelinstandsetzung", "B8", 25, RoadMaintenanceTypeEnum.REPAIR_WORK, null, null, SubjectTypeOfWorksEnum.TUNNEL),

	/**
	 * Tunnelwartung (DATEX II: SituationRecord-roadMaintanceType,
	 * comment-Tunnelwartung, actionPlanIdentifier-B9).
	 */
	Tunnelwartung("Tunnelwartung", "B9", 26, RoadMaintenanceTypeEnum.MAINTENANCE_WORK, null, null, SubjectTypeOfWorksEnum.TUNNEL),

	/**
	 * Bauwerksarbeiten (DATEX II: SituationRecord-constructionWorkType,
	 * comment-Bauwerksarbeiten, actionPlanIdentifier-B10).
	 */
	Bauwerksarbeiten("Bauwerksarbeiten", "B10", 27, null, ConstructionWorkTypeEnum.CONSTRUCTION_WORK, null, null),

	/**
	 * Auf-/Abbau Verkehrsführung (DATEX II:
	 * SituationRecord-roadOrCarriagewayOrLaneManagementType, comment-Auf-/Abbau
	 * Verkehrsführung, actionPlanIdentifier-VF1).
	 */
	AufAbbauVerkehrsfuehrung("Auf-/Abbau Verkehrsführung", "VF1", 28, null, null, RoadOrCarriagewayOrLaneManagementTypeEnum.NEW_ROADWORKS_LAYOUT, null),

	/**
	 * Änderung Verkehrsführung (DATEX II:
	 * SituationRecord-roadOrCarriagewayOrLaneManagementType, comment-Änderung
	 * Verkehrsführung, actionPlanIdentifier-VF2).
	 */
	AenderungVerkehrsfuehrung("Änderung Verkehrsführung", "VF2", 29, null, null, RoadOrCarriagewayOrLaneManagementTypeEnum.LANES_DEVIATED, null),

	/**
	 * Baustelleneinrichtung (DATEX II:
	 * SituationRecord-roadOrCarriagewayOrLaneManagementType,
	 * comment-Baustelleneinrichtung, actionPlanIdentifier-VF3).
	 */
	Baustelleneinrichtung("Baustelleneinrichtung", "VF3", 30, null, null, RoadOrCarriagewayOrLaneManagementTypeEnum.NEW_ROADWORKS_LAYOUT, null),

	/**
	 * Absicherung Baustellenzufahrt (DATEX II:
	 * SituationRecord-roadMaintanceType, comment-Absicherung Baustellenzufahrt,
	 * actionPlanIdentifier-VF4).
	 */
	AbsicherungBaustellenzufahrt("Absicherung Baustellenzufahrt", "VF4", 31, RoadMaintenanceTypeEnum.ROADSIDE_WORK, null, null, null),

	/**
	 * Beseitigung Unfallfolgen (DATEX II: SituationRecord-roadMaintanceType,
	 * comment-Beseitigung Unfallfolgen, actionPlanIdentifier-G1).
	 */
	BeseitigungUnfallfolgen("Beseitigung Unfallfolgen", "G1", 32, RoadMaintenanceTypeEnum.CLEARANCE_WORK, null, null, null),

	/**
	 * Akute Verkehrsgefährdung (DATEX II: SituationRecord-roadMaintanceType,
	 * comment-Akute Verkehrsgefährdung, actionPlanIdentifier-G2).
	 */
	AkuteVerkehrsgefaehrdung("Akute Verkehrsgefährdung", "G2", 33, RoadMaintenanceTypeEnum.ROADWORKS, null, null, null),

	/**
	 * Arbeiten an Parkplätzen/Rastanlagen (DATEX II:
	 * SituationRecord-roadMaintanceType, comment-Arbeiten an
	 * Parkplätzen/Rastanlagen, actionPlanIdentifier-AA1).
	 */
	ArbeitenAnParkplaetzenRastanlagen("Arbeiten an Parkplätzen/Rastanlagen", "AA1", 34, RoadMaintenanceTypeEnum.ROADSIDE_WORK, null, null, null),

	/**
	 * Tiefbau-/Fundamentarbeiten neben der Fahrbahn (DATEX II:
	 * SituationRecord-roadMaintanceType, comment-Tiefbau-/Fundamentarbeiten
	 * neben der Fahrbahn, actionPlanIdentifier-AA2).
	 */
	TiefbauFundamentarbeitenNebenDerFahrbahn("Tiefbau Fundamentarbeiten neben der Fahrbahn", "AA2", 35, RoadMaintenanceTypeEnum.INSTALLATION_WORK, null, null, SubjectTypeOfWorksEnum.BURIED_SERVICES),

	/**
	 * Leitungsarbeiten (DATEX II: SituationRecord-roadMaintanceType,
	 * comment-Leitungsarbeiten, actionPlanIdentifier-AA3).
	 */
	Leitungsarbeiten("Leitungsarbeiten", "AA3", 36, RoadMaintenanceTypeEnum.INSTALLATION_WORK, null, null, SubjectTypeOfWorksEnum.BURIED_CABLES),

	/**
	 * Arbeiten an Geh-/Radwegen (DATEX II: SituationRecord-roadMaintanceType,
	 * comment-Arbeiten an Geh-/Radwegen, actionPlanIdentifier-AA4).
	 */
	ArbeitenAnGehRadwegen("Arbeiten an Geh-/Radwegen", "AA4", 37, RoadMaintenanceTypeEnum.ROADSIDE_WORK, null, null, null),

	/**
	 * Arbeiten an Maut- oder Verkehrszeichenbrücken (DATEX II:
	 * SituationRecord-roadMaintanceType, comment-Arbeiten an Maut- oder
	 * Verkehrszeichenbrücken, actionPlanIdentifier-AA5).
	 */
	ArbeitenAnMautVerkehrszeichenbruecken("Arbeiten an Maut-/Verkehrszeichenbrücken", "AA5", 38, RoadMaintenanceTypeEnum.OVERHEAD_WORKS, null, null, SubjectTypeOfWorksEnum.GANTRY),

	/**
	 * Gerüstarbeiten (DATEX II: SituationRecord-roadMaintanceType,
	 * comment-Gerüstarbeiten, actionPlanIdentifier-AA6).
	 */
	Geruestarbeiten("Gerüstarbeiten", "AA6", 39, RoadMaintenanceTypeEnum.OVERHEAD_WORKS, null, null, SubjectTypeOfWorksEnum.GANTRY),

	/**
	 * Arbeiten an Schutzeinrichtungen (DATEX II:
	 * SituationRecord-roadMaintanceType, comment-Arbeiten an
	 * Schutzeinrichtungen, actionPlanIdentifier-AA7).
	 */
	ArbeitenSchutzeinrichtungen("Arbeiten Schutzeinrichtungen", "AA7", 40, RoadMaintenanceTypeEnum.INSTALLATION_WORK, null, null, SubjectTypeOfWorksEnum.CRASH_BARRIER),

	/**
	 * Schallschutzarbeiten (DATEX II: SituationRecord-roadMaintanceType,
	 * comment-Schallschutzarbeiten, actionPlanIdentifier-AA8).
	 */
	Schallschutzarbeiten("Schallschutzarbeiten", "AA8", 41, RoadMaintenanceTypeEnum.INSTALLATION_WORK, null, null, SubjectTypeOfWorksEnum.NOISE_PROTECTION),

	/**
	 * Bauarbeiten durch DB-AG (DATEX II: SituationRecord-constructionWorkType,
	 * comment-Bauarbeiten durch DB-AG, actionPlanIdentifier-AA9).
	 */
	BauarbeitenDurchDBAG("Bauarbeiten durch DB-AG", "AA9", 42, null, ConstructionWorkTypeEnum.CONSTRUCTION_WORK, null, null),

	/**
	 * Entwässerungsarbeiten (DATEX II: SituationRecord-roadMaintanceType,
	 * comment-Entwässerungsarbeiten, actionPlanIdentifier-P1).
	 */
	Entwaesserungsarbeiten("Entwässerungsarbeiten", "P1", 43, RoadMaintenanceTypeEnum.INSTALLATION_WORK, null, null, SubjectTypeOfWorksEnum.ROADSIDE_DRAINS),

	/**
	 * Grünpflege (DATEX II: SituationRecord-roadMaintanceType,
	 * comment-Grünpflege, actionPlanIdentifier-P2).
	 */
	Gruenpflege("Grünpflege", "P2", 44, RoadMaintenanceTypeEnum.TREE_AND_VEGETATION_CUTTING_WORK, null, null, null),

	/**
	 * Markierungsarbeiten (DATEX II: SituationRecord-roadMaintanceType,
	 * comment-Markierungsarbeiten, actionPlanIdentifier-P3).
	 */
	Markierungsarbeiten("Markierungsarbeiten", "P3", 45, RoadMaintenanceTypeEnum.ROAD_MARKING_WORK, null, null, null),

	/**
	 * Reinigungsarbeiten (DATEX II: SituationRecord-roadMaintanceType,
	 * comment-Reinigungsarbeiten, actionPlanIdentifier-P4).
	 */
	Reinigungsarbeiten("Reinigungsarbeiten", "P4", 46, RoadMaintenanceTypeEnum.SWEEPING_OF_ROAD, null, null, null),

	/**
	 * Beschilderungsarbeiten (DATEX II: SituationRecord-roadMaintanceType,
	 * comment-Beschilderungsarbeiten, actionPlanIdentifier-P5).
	 */
	Beschilderungsarbeiten("Beschilderungsarbeiten", "P5", 47, RoadMaintenanceTypeEnum.INSTALLATION_WORK, null, null, SubjectTypeOfWorksEnum.ROAD_SIGNS),

	/**
	 * Vermessungsarbeiten (DATEX II: SituationRecord-roadMaintanceType,
	 * comment-Vermessungsarbeiten, actionPlanIdentifier-U1).
	 */
	Vermessungsarbeiten("Vermessungsarbeiten", "U1", 48, RoadMaintenanceTypeEnum.ROADSIDE_WORK, null, null, null),

	/**
	 * Bodenuntersuchungen (DATEX II: SituationRecord-roadMaintanceType,
	 * comment-Bodenuntersuchungen, actionPlanIdentifier-U2).
	 */
	Bodenuntersuchungen("Bodenuntersuchungen", "U2", 49, RoadMaintenanceTypeEnum.ROADSIDE_WORK, null, null, null),

	/**
	 * Sonstiges (DATEX II: SituationRecord-roadMaintanceType,
	 * comment-Sonstiges, actionPlanIdentifier-S1).
	 */
	Sonstiges("Sonstiges", "S1", 50, RoadMaintenanceTypeEnum.OTHER, null, null, null);

	/**
	 * Gibt eine passende Instanz zur&uuml;ck.
	 *
	 * @param d2text
	 *            XML-Wert
	 * @return zum numerischen Wert passende Instanz
	 * @throws Datex2BaustelleException
	 *             bei ung&uuml;ltigem Wert
	 */
	public static Datex2ArtDerMassnahmeEnum getInstance(final String d2text) throws Datex2BaustelleException {
		for (Datex2ArtDerMassnahmeEnum adm : Datex2ArtDerMassnahmeEnum.values()) {
			if (adm.getActionPlanIdentifier().equals(d2text)) {
				return adm;
			}
		}
		throw new Datex2BaustelleException("Keine ArtDerMassnahme mit XML-Wert=" + d2text + " definiert.");
	}

	/**
	 * Gibt eine passende Instanz zur&uuml;ck.
	 *
	 * @param davwert
	 *            DAV-Wert
	 * @return zum numerischen Wert passende Instanz
	 * @throws Datex2BaustelleException
	 *             bei ung&uuml;ltigem Wert
	 */
	public static Datex2ArtDerMassnahmeEnum getInstance(final int davwert) throws Datex2BaustelleException {
		for (Datex2ArtDerMassnahmeEnum adm : Datex2ArtDerMassnahmeEnum.values()) {
			if (adm.getDavId() == davwert) {
				return adm;
			}
		}
		throw new Datex2BaustelleException(
				"Keine Datex2-'Datex2ArtDerMassnahmeEnum' zu DAV-Wert=" + davwert + " definiert.");
	}

	/**
	 * textueller Wert.
	 */
	private final String actionPlanIdentifier;

	/**
	 * numerischer Wert.
	 */
	private int id;

	private String beschreibung;

	private RoadMaintenanceTypeEnum roadMaintenanceTypeEnum;

	private ConstructionWorkTypeEnum constructionWorkTypeEnum;

	private RoadOrCarriagewayOrLaneManagementTypeEnum roadOrCarriagewayOrLaneManagementTypeEnum;

	private SubjectTypeOfWorksEnum subjectTypeOfWorksEnum;

	/**
	 * Privater Konstruktor.
	 *
	 * @param actionPlanIdentifier
	 *            textueller Wert
	 * @param david
	 *            numerischer DAV-Wert
	 */
	Datex2ArtDerMassnahmeEnum(final String name, final String datex2ActionPlanIdentifier, final int david,
			final RoadMaintenanceTypeEnum roadMaintenanceTypeEnum,
			final ConstructionWorkTypeEnum constructionWorkTypeEnum,
			final RoadOrCarriagewayOrLaneManagementTypeEnum roadOrCarriagewayOrLaneManagementTypeEnum,
			final SubjectTypeOfWorksEnum subjectTypeOfWorksEnum) {
		this.beschreibung = name;
		this.actionPlanIdentifier = datex2ActionPlanIdentifier;
		this.id = david;
		this.roadMaintenanceTypeEnum = roadMaintenanceTypeEnum;
		this.constructionWorkTypeEnum = constructionWorkTypeEnum;
		this.roadOrCarriagewayOrLaneManagementTypeEnum = roadOrCarriagewayOrLaneManagementTypeEnum;
		this.subjectTypeOfWorksEnum = subjectTypeOfWorksEnum;
	}

	/**
	 * Gibt den numerischen DAV-Wert zur&uuml;ck.
	 *
	 * @return numerischer DAV-Wert
	 */
	public int getDavId() {
		return id;
	}

	/**
	 * Gibt den DatexII-ActionPlanIdentifier zur&uuml;ck.
	 *
	 * @return DatexII-ActionPlanIdentifier
	 */
	public String getActionPlanIdentifier() {
		return actionPlanIdentifier;
	}

	/**
	 * Gibt die Beschreibung zur&uuml;ck.
	 * 
	 * @return Beschreibung
	 */
	public String getBeschreibung() {
		return beschreibung;
	}

	/**
	 * Gibt den zugeh&ouml;rigen RoadMaintenanceTypeEnum zur&uuml;ck.
	 * 
	 * @return {@link RoadMaintenanceTypeEnum}
	 */
	public RoadMaintenanceTypeEnum getRoadMaintenanceTypeEnum() {
		return roadMaintenanceTypeEnum;
	}

	/**
	 * Gibt den zugeh&ouml;rigen ConstructionWorkTypeEnum zur&uuml;ck.
	 * 
	 * @return {@link ConstructionWorkTypeEnum}
	 */
	public ConstructionWorkTypeEnum getConstructionWorkTypeEnum() {
		return constructionWorkTypeEnum;
	}

	/**
	 * Gibt den zugeh&ouml;rigen RoadOrCarriagewayOrLaneManagementTypeEnum
	 * zur&uuml;ck.
	 * 
	 * @return {@link RoadOrCarriagewayOrLaneManagementTypeEnum}
	 */
	public RoadOrCarriagewayOrLaneManagementTypeEnum getRoadOrCarriagewayOrLaneManagementTypeEnum() {
		return roadOrCarriagewayOrLaneManagementTypeEnum;
	}

	/**
	 * Gibt den zugeh&ouml;rigen SubjectTypeOfWorksEnum zur&uuml;ck.
	 * 
	 * @return {@link SubjectTypeOfWorksEnum}
	 */
	public SubjectTypeOfWorksEnum getSubjectTypeOfWorksEnum() {
		return subjectTypeOfWorksEnum;
	}
}
