/*
 * Plug-in KEx DATEX II - Baustellen
 * Copyright (C) 2018 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.datex2.plugins.konvertierung.impl.elemente;

import de.bsvrz.kex.datex2.plugins.konvertierung.impl.Datex2BaustelleException;
import eu.datex2.schema.dynamisch.baustellen.MobilityEnum;

/**
 * Umsetzung Datk <code>att.mdmBisMobilOderStationär</code> in Datex2
 * <code>MobilityEnum</code>.
 * 
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id: $
 */
public enum Datex2MobilityEnum {
	/**
	 * unbekannt&nbsp;0&nbsp;Art der Arbeitsstelle ist nicht bekannt (DATEX II:
	 * unknown).
	 */
	Unbekannt(MobilityEnum.UNKNOWN, 0),

	/**
	 * stationär&nbsp;1&nbsp;Arbeitsstelle ist stationär eingerichtet (DATEX II:
	 * stationary).
	 */
	Stationaer(MobilityEnum.STATIONARY, 1),

	/**
	 * mobil&nbsp;2&nbsp;Arbeitsstelle ist mobil, Wanderbaustelle) (DATEX II:
	 * mobile).
	 */
	Mobil(MobilityEnum.MOBILE, 2);

	/**
	 * Gibt eine passende Instanz zur&uuml;ck.
	 *
	 * @param davwert
	 *            DAV-Wert
	 * @return zum numerischen Wert passende Instanz
	 * @throws Datex2BaustelleException
	 *             bei ung&uuml;ltigem Wert
	 */
	public static Datex2MobilityEnum getInstance(final int davwert) throws Datex2BaustelleException {
		for (Datex2MobilityEnum adm : Datex2MobilityEnum.values()) {
			if (adm.getDavId() == davwert) {
				return adm;
			}
		}
		throw new Datex2BaustelleException("Keine Datex2-'MobilityEnum' zu DAV-Wert=" + davwert + " definiert.");
	}

	/**
	 * Datex2-Wert.
	 */
	private final MobilityEnum datexWert;

	/**
	 * Gibt den DatexII-Wert zur&uuml;ck.
	 * 
	 * @return {@link MobilityEnum}
	 */
	public MobilityEnum getDatexWert() {
		return datexWert;
	}

	/**
	 * numerischer Wert.
	 */
	private int david;

	/**
	 * Privater Konstruktor.
	 *
	 * @param value
	 *            textueller Wert
	 * @param id
	 *            numerischer Wert
	 */
	Datex2MobilityEnum(final MobilityEnum value, final int david) {
		this.datexWert = value;
		this.david = david;
	}

	/**
	 * Gibt den numerischen Wert zur&uuml;ck.
	 *
	 * @return numerischer Wert der Himmelsrichtung
	 */
	public int getDavId() {
		return david;
	}

}
