/*
 * Plug-in KEx DATEX II - Baustellen
 * Copyright (C) 2018 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.datex2.plugins.konvertierung.impl.elemente;

import eu.datex2.schema.dynamisch.baustellen.MultilingualString;
import eu.datex2.schema.dynamisch.baustellen.MultilingualString.Values;
import eu.datex2.schema.dynamisch.baustellen.MultilingualStringValue;

/**
 * Hilfsklasse zur Verarbeitung von {@link MultilingualString}.
 *
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id: $
 */

public final class Datex2MultilingualString {

	private Datex2MultilingualString() {
		// zur Beruhigung von checkstyle
	}

	/**
	 * Wandelt {@link MultilingualString} in String um.
	 * 
	 * @param mstring
	 *            {@link MultilingualString}
	 * @return String
	 */
	public static String datex2MultilingualStringToString(final MultilingualString mstring) {
		final StringBuffer ergebnis = new StringBuffer();
		final Values values = mstring.getValues();
		for (MultilingualStringValue msv : values.getValue()) {
			ergebnis.append(msv.getValue());
		}

		return ergebnis.toString();
	}

	/**
	 * erzeugt einen Multilingualen String.
	 * 
	 * @param s
	 *            Text fuer den deutschen Text des Multiligualen Strings
	 * @return MultilingualString
	 */

	public static MultilingualString konvertiereString(final String s) {
		final MultilingualString ms = new MultilingualString();
		final Values vs = new Values();
		final MultilingualStringValue msv = new MultilingualStringValue();
		msv.setLang("DE");
		msv.setValue(s);
		vs.getValue().add(msv);
		ms.setValues(vs);
		return ms;
	}

}
